package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Apr 5, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Engine translates natural language questions to Cypher and executes them.
New creates a new NL query engine. Requires ANTHROPIC_API_KEY env var.
Query translates a natural language question to Cypher and executes it.
type Response struct {
Question string `json:"question"`
GeneratedQuery string `json:"generated_query"`
Result *cypher.Result `json:"result"`
}
Response contains the generated Cypher and query results.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.