Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterQueryServiceServer(s grpc.ServiceRegistrar, srv QueryServiceServer)
- type CypherRequest
- type NLRequest
- type NLResponse
- func (*NLResponse) Descriptor() ([]byte, []int)deprecated
- func (x *NLResponse) GetGeneratedCypher() string
- func (x *NLResponse) GetResults() *QueryResponse
- func (*NLResponse) ProtoMessage()
- func (x *NLResponse) ProtoReflect() protoreflect.Message
- func (x *NLResponse) Reset()
- func (x *NLResponse) String() string
- type QueryResponse
- func (*QueryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *QueryResponse) GetColumns() []string
- func (x *QueryResponse) GetRows() []*Row
- func (*QueryResponse) ProtoMessage()
- func (x *QueryResponse) ProtoReflect() protoreflect.Message
- func (x *QueryResponse) Reset()
- func (x *QueryResponse) String() string
- type QueryServiceClient
- type QueryServiceServer
- type Row
- type UnimplementedQueryServiceServer
- type UnsafeQueryServiceServer
Constants ¶
const ( QueryService_Cypher_FullMethodName = "/instgraph.query.v1.QueryService/Cypher" QueryService_NaturalLanguage_FullMethodName = "/instgraph.query.v1.QueryService/NaturalLanguage" )
Variables ¶
var File_query_proto protoreflect.FileDescriptor
var QueryService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "instgraph.query.v1.QueryService", HandlerType: (*QueryServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Cypher", Handler: _QueryService_Cypher_Handler, }, { MethodName: "NaturalLanguage", Handler: _QueryService_NaturalLanguage_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "query.proto", }
QueryService_ServiceDesc is the grpc.ServiceDesc for QueryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterQueryServiceServer ¶
func RegisterQueryServiceServer(s grpc.ServiceRegistrar, srv QueryServiceServer)
Types ¶
type CypherRequest ¶
type CypherRequest struct {
Query string `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
// contains filtered or unexported fields
}
func (*CypherRequest) Descriptor
deprecated
func (*CypherRequest) Descriptor() ([]byte, []int)
Deprecated: Use CypherRequest.ProtoReflect.Descriptor instead.
func (*CypherRequest) GetQuery ¶
func (x *CypherRequest) GetQuery() string
func (*CypherRequest) ProtoMessage ¶
func (*CypherRequest) ProtoMessage()
func (*CypherRequest) ProtoReflect ¶
func (x *CypherRequest) ProtoReflect() protoreflect.Message
func (*CypherRequest) Reset ¶
func (x *CypherRequest) Reset()
func (*CypherRequest) String ¶
func (x *CypherRequest) String() string
type NLRequest ¶
type NLRequest struct {
Question string `protobuf:"bytes,1,opt,name=question,proto3" json:"question,omitempty"`
// contains filtered or unexported fields
}
func (*NLRequest) Descriptor
deprecated
func (*NLRequest) GetQuestion ¶
func (*NLRequest) ProtoMessage ¶
func (*NLRequest) ProtoMessage()
func (*NLRequest) ProtoReflect ¶
func (x *NLRequest) ProtoReflect() protoreflect.Message
type NLResponse ¶
type NLResponse struct {
GeneratedCypher string `protobuf:"bytes,1,opt,name=generated_cypher,json=generatedCypher,proto3" json:"generated_cypher,omitempty"`
Results *QueryResponse `protobuf:"bytes,2,opt,name=results,proto3" json:"results,omitempty"`
// contains filtered or unexported fields
}
func (*NLResponse) Descriptor
deprecated
func (*NLResponse) Descriptor() ([]byte, []int)
Deprecated: Use NLResponse.ProtoReflect.Descriptor instead.
func (*NLResponse) GetGeneratedCypher ¶
func (x *NLResponse) GetGeneratedCypher() string
func (*NLResponse) GetResults ¶
func (x *NLResponse) GetResults() *QueryResponse
func (*NLResponse) ProtoMessage ¶
func (*NLResponse) ProtoMessage()
func (*NLResponse) ProtoReflect ¶
func (x *NLResponse) ProtoReflect() protoreflect.Message
func (*NLResponse) Reset ¶
func (x *NLResponse) Reset()
func (*NLResponse) String ¶
func (x *NLResponse) String() string
type QueryResponse ¶
type QueryResponse struct {
Columns []string `protobuf:"bytes,1,rep,name=columns,proto3" json:"columns,omitempty"`
Rows []*Row `protobuf:"bytes,2,rep,name=rows,proto3" json:"rows,omitempty"`
// contains filtered or unexported fields
}
func (*QueryResponse) Descriptor
deprecated
func (*QueryResponse) Descriptor() ([]byte, []int)
Deprecated: Use QueryResponse.ProtoReflect.Descriptor instead.
func (*QueryResponse) GetColumns ¶
func (x *QueryResponse) GetColumns() []string
func (*QueryResponse) GetRows ¶
func (x *QueryResponse) GetRows() []*Row
func (*QueryResponse) ProtoMessage ¶
func (*QueryResponse) ProtoMessage()
func (*QueryResponse) ProtoReflect ¶
func (x *QueryResponse) ProtoReflect() protoreflect.Message
func (*QueryResponse) Reset ¶
func (x *QueryResponse) Reset()
func (*QueryResponse) String ¶
func (x *QueryResponse) String() string
type QueryServiceClient ¶
type QueryServiceClient interface {
Cypher(ctx context.Context, in *CypherRequest, opts ...grpc.CallOption) (*QueryResponse, error)
NaturalLanguage(ctx context.Context, in *NLRequest, opts ...grpc.CallOption) (*NLResponse, error)
}
QueryServiceClient is the client API for QueryService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewQueryServiceClient ¶
func NewQueryServiceClient(cc grpc.ClientConnInterface) QueryServiceClient
type QueryServiceServer ¶
type QueryServiceServer interface {
Cypher(context.Context, *CypherRequest) (*QueryResponse, error)
NaturalLanguage(context.Context, *NLRequest) (*NLResponse, error)
// contains filtered or unexported methods
}
QueryServiceServer is the server API for QueryService service. All implementations must embed UnimplementedQueryServiceServer for forward compatibility.
type Row ¶
type Row struct {
Values map[string]string `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Row) Descriptor
deprecated
func (*Row) ProtoMessage ¶
func (*Row) ProtoMessage()
func (*Row) ProtoReflect ¶
func (x *Row) ProtoReflect() protoreflect.Message
type UnimplementedQueryServiceServer ¶
type UnimplementedQueryServiceServer struct{}
UnimplementedQueryServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedQueryServiceServer) Cypher ¶
func (UnimplementedQueryServiceServer) Cypher(context.Context, *CypherRequest) (*QueryResponse, error)
func (UnimplementedQueryServiceServer) NaturalLanguage ¶
func (UnimplementedQueryServiceServer) NaturalLanguage(context.Context, *NLRequest) (*NLResponse, error)
type UnsafeQueryServiceServer ¶
type UnsafeQueryServiceServer interface {
// contains filtered or unexported methods
}
UnsafeQueryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to QueryServiceServer will result in compilation errors.